import React, { useState } from 'react';

import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';

import SwipeableDrawer from '@material-ui/core/SwipeableDrawer';
import List from '@material-ui/core/List';
import Divider from '@material-ui/core/Divider';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';

import HomeIcon from '@material-ui/icons/Home';
import ListIcon from '@material-ui/icons/List';
import SettingsIcon from '@material-ui/icons/Settings';

import { makeStyles, createMuiTheme, MuiThemeProvider } from '@material-ui/core/styles';

import { withRouter } from 'react-router-dom';

const useStyles = makeStyles(theme => ({
    root: {
        flexGrow: 1,
    },
    menuButton: {
        marginRight: theme.spacing(2),
    },
    title: {
        flexGrow: 1,
    },

    list: {
        width: 250,
    },
    fullList: {
        width: 'auto',
    },    
}));


// layout copied from material-ui
const Layout = withRouter(({ history, children, location }) => {
    const classes = useStyles();
    const [open, toggleDrawer] = useState(false);

    function navigate(target) {
        return () => {
            toggleDrawer(false);
            history.push(target);
        }
    }

    let title = document.title;
    if (location.pathname == "/projects") {
        title = "Projects";
    } else if (location.pathname == "/settings") {
        title = "Settings";
    }

    return (
        <div className={ classes.root }>
            <AppBar position="static">
                <Toolbar>
                    <IconButton edge="start" className={ classes.menuButton } color="inherit" aria-label="menu" onClick={ () => toggleDrawer(!open) }>
                        <MenuIcon />
                    </IconButton>
                    <Typography variant="h6" className={ classes.title }>
                        { title }
                    </Typography>
                </Toolbar>
            </AppBar>


            { children }

            <SwipeableDrawer
                open={ open }
                onClose={ () => toggleDrawer(false) }
                onOpen={ () => toggleDrawer(true) }
                >
                
                <List>
                    <ListItem button onClick={ navigate("/") }>
                        <ListItemIcon><HomeIcon /></ListItemIcon>
                        <ListItemText primary="Home" />
                    </ListItem>
                </List>
                <List>
                    <ListItem button onClick={ navigate("/projects") }>
                        <ListItemIcon><ListIcon /></ListItemIcon>
                        <ListItemText primary="Projects" />
                    </ListItem>
                </List>
                <Divider/>
                <List>
                    <ListItem button onClick={ navigate("/settings") }>
                        <ListItemIcon><SettingsIcon /></ListItemIcon>
                        <ListItemText primary="Settings" />
                    </ListItem>
                </List>

            </SwipeableDrawer>

        </div>
    );
});


export default Layout;